<?php
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
class MTWooFeaturedProductsSettingsPage
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'mtw_plugin_menu' ) );
        add_action( 'admin_init', array( $this, 'mtw_settings_init' ) );
    }

    /**
     * Add options page
     */
    public function mtw_plugin_menu()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings', 
            'MT Products Carousel for WooCommerce', 
            'manage_options', 
            'mt_woocommerce_featured_products', 
            array( $this, 'create_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option( 'mt_featured_settings' );
        ?>
		<style>
			tr.cats_selected,
			tr.products_selected,
			tr.exclude_products	{
				display: none;
			}
			tr.cats_selected.show, 
			tr.products_selected.show,
			tr.exclude_products.show {
				display: table-row;
			}
		
			.mt-pi-contain h1 {
				background: #540159;
				padding: 20px;
				font-weight: 900;
				color: #fff;
				letter-spacing: 1px;
			}
			.mt-pi-contain h2 {
				font-weight: 900;
			}
			div#wpfooter,div#wpfooter a {
				color: #fff;
			}
			.mt-pi-contain {
				border: 1px solid #ccc;
				
				border-radius: 12px;
				background: #ffffff;
				box-shadow: 11px 11px 17px #b8b8b8, -11px -11px 17px #ffffff;
				margin-bottom: 3em;
			}
			.mt-pi-contain:before, .mt-pi-contain:after,
			.usage:before, .usage:after {
				display:table;
				content:'';
				clear:both;
			}
			.usage {
				margin: 1.5em;
				box-shadow: 11px 11px 17px #b8b8b8, -11px -11px 17px #fbfbfb;
				border-radius: 7px;
				padding: 0em 1em;
				background: #fbfbfb;
			}
			.mt-pi-contain select,
			.mt-pi-contain input[type=text],
			.mt-pi-contain input[type=number] {
				height: 45px;
			}
			form {
				padding: 15px;
			}
			@media(min-width:1400px){
				.usage {
					float: right;
				}

				form {
					float: left;
				}
				
			}
		</style>
        <div class="wrap">
		
			<div class="mt-pi-contain" >
				<h1 class="">MT Products Carousel for WooCommerce</h1>
				<div class="usage">
					<h2>Shortcode Usage:</h2>
					<p><strong>Add to Page</strong> - [mt-featuredproducts]</p>
					<p><strong>Add to Template</strong> - &#60;?php echo do_shortcode('[mt-featuredproducts]'); ?&#62;</p>
				</div>
			
				<form method="post" action="options.php">
				<?php
					// This prints out all hidden setting fields
					settings_fields( 'mtoption-group-1' );
					do_settings_sections( 'mt_woocommerce_featured_products' );;
					submit_button();
				?>
				</form>
				
			</div>
			<div class="mt-pi-contain" style="padding: 0 15px;">
				<p>For information on Order / Orderby settings see <a href="https://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">https://codex.wordpress.org/Class_Reference/WP_Query</a></p>
				<p>For information on Slick settings see <a href="http://kenwheeler.github.io/slick/" target="_blank">http://kenwheeler.github.io/slick/</a></p>
				
				<p>This plugin has been developed using Slick slider developed by Ken Wheeler</p>
				<p style="text-align:right;margin-top:1.5em;">Version 3.0</p>
			</div>
		
		</div>
		<script>
			jQuery(function(){
			
				/*Category ID Field Conditional*/
				if ( jQuery('#products_type option:selected').val() == 'Category') {
					jQuery('.cats_selected').addClass('show');
				}
				if ( jQuery('#products_type option:selected').val() == 'All') {
					jQuery('.products_selected').addClass('show');
					jQuery('.exclude_products').removeClass('show');
				}
				
				jQuery('body').on('change','#products_type',function() {
					if (jQuery(this).val() == 'All') {
						jQuery('.products_selected').addClass('show');
						jQuery('.products_selected').siblings().removeClass('show');
					} 
					if (jQuery(this).val() == 'Featured') {
						jQuery('.cats_selected').removeClass('show');
						jQuery('.products_selected').removeClass('show');
						jQuery('.exclude_products').addClass('show');
					} 
					if (jQuery(this).val() == 'Category') {
						jQuery('.cats_selected').siblings().removeClass('show');
						jQuery('.cats_selected').addClass('show');
						jQuery('.exclude_products').addClass('show');
					} 
				});
			});
		</script>
        <?php
    }

    /**
     * Register and add settings
     */
    public function mtw_settings_init()
    {          
        register_setting(
            'mtoption-group-1', // Option group
            'mt_featured_settings', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'options_section_id', // ID
            'Options', // Title
            array( $this, 'print_section_info' ), // Callback
            'mt_woocommerce_featured_products' // Page
        );
		add_settings_field(
            'products_type', // ID
            'Select Slider Type', // Title 
            array( $this, 'products_type_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'products_type' ) // Args
        );
		add_settings_field(
            'products_selected', // ID
            'Products to Show', // Title
            array( $this, 'products_selected_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section  
			array( 'class' => 'products_selected' ) // Args
        );
		add_settings_field(
            'cats_selected', // ID
            'Categories to Show', // Title
            array( $this, 'cats_selected_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'cats_selected' ) // Args
        );
		add_settings_field(
            'exclude_products', // ID
            'Exclude Products', // Title
            array( $this, 'exclude_products_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'exclude_products show' ) // Args
        );
		add_settings_field(
            'product_images', // ID
            'Product Image Size', // Title 
            array( $this, 'product_images_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'product_images' ) // Args
        );
		add_settings_field(
            'products_title', // ID
            'Show Product Title?', // Title
            array( $this, 'title_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'products_title' ) // Args
        );
		add_settings_field(
            'products_price', // ID
            'Show Product Price?', // Title
            array( $this, 'price_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'products_price' ) // Args
        );
		add_settings_field(
            'product_add_to_cart', // ID
            'Show Add to Cart?', // Title
            array( $this, 'add_to_cart_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'product_add_to_cart' ) // Args
        );
        add_settings_field(
            'max_products', // ID
            'Maximum Number of Products', // Title
            array( $this, 'products_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'max_products' ) // Args
        );
        add_settings_field(
            'order', // ID
            'Order', // Title
            array( $this, 'order_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'order' ) // Args
        );
        add_settings_field(
            'orderby', // ID
            'OrderBy', // Title
            array( $this, 'orderby_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'orderby' ) // Args
        );
        add_settings_field(
            'slick-settings', // ID
            'Slick Settings', // Title
            array( $this, 'textarea_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'slick-settings' ) // Args
        );
		add_settings_field(
            'exclude-slick', // ID
            'Slick Slider CSS/JS', // Title
            array( $this, 'slick_callback' ), // Callback
            'mt_woocommerce_featured_products', // Page
            'options_section_id', // Section
			array( 'class' => 'exclude-slick' ) // Args
        );
    }

    /**
     * Sanitize each setting field as needed
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input ) {
        $new_input = array();
		if( isset( $input['products_type'] ) )
            $new_input['products_type'] = sanitize_text_field( $input['products_type'] );
		if( isset( $input['products_selected'] ) )
            $new_input['products_selected'] = sanitize_text_field( $input['products_selected'] );
		if( isset( $input['cats_selected'] ) )
            $new_input['cats_selected'] = sanitize_text_field( $input['cats_selected'] );
		if( isset( $input['exclude_products'] ) )
            $new_input['exclude_products'] = sanitize_text_field( $input['exclude_products'] );
		if( isset( $input['product_images'] ) )
            $new_input['product_images'] = sanitize_text_field( $input['product_images'] );
		if( isset( $input['product_add_to_cart'] ) )
            $new_input['product_add_to_cart'] = sanitize_text_field( $input['product_add_to_cart'] );
		if( isset( $input['products_title'] ) )
            $new_input['products_title'] = sanitize_text_field( $input['products_title'] );
		if( isset( $input['products_price'] ) )
            $new_input['products_price'] = sanitize_text_field( $input['products_price'] );
        if( isset( $input['max_products'] ) )
            $new_input['max_products'] = sanitize_text_field( $input['max_products'] );
		if( isset( $input['order'] ) )
            $new_input['order'] = sanitize_text_field( $input['order'] );
		if( isset( $input['orderby'] ) )
            $new_input['orderby'] = sanitize_text_field( $input['orderby'] );
        if( isset( $input['slick-settings'] ) )
            $new_input['slick-settings'] = sanitize_text_field( $input['slick-settings'] );
		if( isset( $input['exclude-slick'] ) )
            $new_input['exclude-slick'] = sanitize_text_field( $input['exclude-slick'] );
        return $new_input;
    }

    public function print_section_info() {
        print '';
    }

	public function products_type_callback() {
	
		$items = array(
			array('Featured', 'Featured Products'),
			array('All', 'Specific Products'),
			array('Category', 'Specific Categories')
		);
		
		echo '<select id="products_type" name="mt_featured_settings[products_type]">';
		
		foreach($items as $item) {
			
			$selected = ($this->options['products_type']==$item[0]) ? 'selected="selected"' : '';
			
			echo '<option value="'.$item[0].'" '.$selected.'>'.$item[1].'</option>';
		}
		echo '</select>';
		
	}
	public function products_selected_callback() {
        printf(
            '<input type="text" id="products_selected" name="mt_featured_settings[products_selected]" value="%s" placeholder="0,1,2" min="-1"/><br/><span style="font-size: 0.85em;"><strong>Enter products IDs separated by commas</strong><br>All Products will show if  field is left empty. </span>',
            isset( $this->options['products_selected'] ) ? esc_attr( $this->options['products_selected']) : ''
        );
    }
	public function cats_selected_callback() {
        printf(
            '<input type="text" id="cats_selected" name="mt_featured_settings[cats_selected]" value="%s" placeholder="0,1,2" min="-1"/><br/><span style="font-size: 0.85em;"><strong>Enter category IDs separated by commas</strong><br>If a category ID is not entered, no products will display. </span>',
            isset( $this->options['cats_selected'] ) ? esc_attr( $this->options['cats_selected']) : ''
        );
    }
	
	public function exclude_products_callback() {
        printf(
            '<input type="text" id="exclude_products" name="mt_featured_settings[exclude_products]" value="%s" placeholder="0,1,2" /><br/><span style="font-size: 0.85em;"><strong>Enter products IDs separated by commas</strong></span>',
            isset( $this->options['exclude_products'] ) ? esc_attr( $this->options['exclude_products']) : ''
        );
    }
	public function product_images_callback() {
	
		$items = get_intermediate_image_sizes();
		
		echo '<select id="product_images" name="mt_featured_settings[product_images]">';
		
		foreach($items as $item) {
			
			$selected = ($this->options['product_images']==$item) ? 'selected="selected"' : '';
			
			echo '<option value="'.$item.'" '.$selected.'>'.$item.'</option>';
		}
		echo '</select>';
		
	}
	public function title_callback() {

		$items = array('Yes','No');
		
		echo '<select id="products_title" name="mt_featured_settings[products_title]">';
		
		foreach($items as $item) {
			
			$selected = ($this->options['products_title']==$item) ? 'selected="selected"' : '';
			
			echo '<option value="'.$item.'" '.$selected.'>'.$item.'</option>';
		}
		echo '</select>';
	}
	public function price_callback() {

		$items = array('Yes','No');
		
		echo '<select id="products_price" name="mt_featured_settings[products_price]">';
		
		foreach($items as $item) {
			
			$selected = ($this->options['products_price']==$item) ? 'selected="selected"' : '';
			
			echo '<option value="'.$item.'" '.$selected.'>'.$item.'</option>';
		}
		echo '</select>';
	}
	public function add_to_cart_callback() {

		$items = array('Yes','No');
		
		echo '<select id="product_add_to_cart" name="mt_featured_settings[product_add_to_cart]">';
		
		foreach($items as $item) {
			
			$selected = ($this->options['product_add_to_cart']==$item) ? 'selected="selected"' : '';
			
			echo '<option value="'.$item.'" '.$selected.'>'.$item.'</option>';
		}
		echo '</select>';
	}
	
    public function products_callback() {
        printf(
            '<input type="number" id="max_products" name="mt_featured_settings[max_products]" value="%s" placeholder="-1" min="-1"/><br/><span style="font-size: 0.85em;">Default: All Products</span>',
            isset( $this->options['max_products'] ) ? esc_attr( $this->options['max_products']) : ''
        );
    }
	public function order_callback() {
 
		$items = array(
			array('ASC', 'Ascending'),
			array('DESC', 'Descending')
		
		);
		foreach($items as $item) {
			$checked = ($this->options['order']==$item[0]) ? ' checked="checked" ' : '';
			echo "<label><input ".$checked." value='$item[0]' name='mt_featured_settings[order]' type='radio' /> $item[1]</label><br />";
		}
    }
	public function orderby_callback() {

		$items = array('title', 'ID', 'author',  'name', 'date', 'rand');
		foreach($items as $item) {
			$checked = ($this->options['orderby']==$item) ? ' checked="checked" ' : '';
			echo "<label><input ".$checked." value='$item' name='mt_featured_settings[orderby]' type='radio' /> $item</label><br />";
		}
    }

    public function textarea_callback() {
        printf(
            '<textarea id="slick-settings" name="mt_featured_settings[slick-settings]" value="" rows="10" cols="50" placeholder="dots: true, &#10;arrows: false, &#10;infinite: false, &#10;speed: 300, &#10;slidesToShow: 3,&#10;slidesToScroll: 1, &#10;lazyLoad: \'ondemand\', &#10;autoplay: true, &#10;speed: 3000, &#10;autoplaySpeed: 3500,&#10; responsive: [ &#10;{ breakpoint: 768, &#10;settings: { &#10;slidesToShow: 2 &#10;} &#10;}, &#10;{ breakpoint: 480, &#10;settings: { &#10;slidesToShow: 1&#10; } &#10;} ]">%s</textarea>',
            isset( $this->options['slick-settings'] ) ? esc_attr( $this->options['slick-settings']) : ''
        );
    }
	public function slick_callback() {
		
		if(isset($this->options['exclude-slick'])) { $checked = ' checked="checked" '; } else {$checked = '';}
		
		echo '<input type="checkbox" id="exclude-slick" name="mt_featured_settings[exclude-slick]" value="1" '.$checked.'> <span style="font-size: 0.85em;">If you are already loading Slick Slider elsewhere in your setup, you can disable this.</span>';
    }
}

if( is_admin() )
    $my_settings_page = new MTWooFeaturedProductsSettingsPage();