<?php
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );
/**
 * Plugin Name: MT Products Carousel for WooCommerce 
 * Plugin URI: https://ithoughtyoucouldusethis.com/
 * Description: Simple product carousel for WooCommerce using the slick jQuery plugin
 * Version: 3.0
 * Author: Matthew Tresch - ithoughtyoucouldusethis.com
 * License: GPLv3 or later
 */
 
require_once( 'admin/mt-woo-carousel-admin.php' );

/*REGISTER REQUIRED FILES*/
function mt_featured_wp_enqueue_scripts() {
	$pluginOptions = get_option('mt_featured_settings');
	if( isset( $pluginOptions['exclude-slick'] ) ) {
		wp_register_style( 'slickCSS', plugins_url( '/slick/slick.css', __FILE__ ) );
		wp_register_style( 'slickCSS1', plugins_url( '/slick/slick-theme.css', __FILE__ ) );
		wp_register_script( 'slickJS', plugins_url( '/slick/slick.min.js', __FILE__ ), array('jquery') );
	}
	wp_register_style( 'sliderCSS', plugins_url( '/css/style.css', __FILE__ ) );
}
add_action( 'wp_enqueue_scripts', 'mt_featured_wp_enqueue_scripts' );


/*SHORTCODE*/
function MTProductCarouselShortcode() {
	$pluginOptions = get_option('mt_featured_settings');
	$mtfeatured = '';
	if (isset($pluginOptions)) {
		
		$typeOption = $pluginOptions['products_type'] ?? 'featured';
		$productChoiceOption = $pluginOptions['products_selected'] ?? '';
		$catChoiceOption = $pluginOptions['cats_selected'] ?? '';
		$excluded = $pluginOptions['exclude_products'] ?? '';
		$imageSize = $pluginOptions['product_images'] ?? 'medium';
		$addToCart = $pluginOptions['product_add_to_cart'] ?? '';
		$titleOption = $pluginOptions['products_title'] ?? 'Yes';
		$priceOption = $pluginOptions['products_price'] ?? 'Yes';
		$maxOption = $pluginOptions['max_products'] ?? '-1';
		$orderOption = $pluginOptions['order'] ?? 'ASC';
		$orderbyOption = $pluginOptions['orderby'] ?? 'title';

		$excludedArray = explode(',', $excluded);
		
		if($typeOption === 'All'){
			/* Specific Products */
			if($productChoiceOption != '')	{
				$productArray = explode(',', $productChoiceOption);
				$query_slider = array(
					'post_type' => 'product',
					'posts_per_page' => $maxOption,
					'order' => $orderOption,
					'orderby' => $orderbyOption,
					'post__in' => $productArray,
				 );
			}else{
				$query_slider = array(
					'post_type' => 'product',
					'posts_per_page' => $maxOption,
					'order' => $orderOption,
					'orderby' => $orderbyOption,
				 );
			}
		} elseif($typeOption === 'Featured') {
			/* Featured Products */
			 $query_slider = array(
				'post_type' => 'product',
				'posts_per_page' => $maxOption,
				'order' => $orderOption,
				'orderby' => $orderbyOption,
				'tax_query' => array(
					array (
						   'taxonomy' => 'product_visibility',
							'field'    => 'name',
							'terms'    => 'featured',
							'operator' => 'IN',
					)
				),
				'post__not_in' => $excludedArray
			 );
			
		} else {
			/* Specific Categories */
			$catArray = explode(',', $catChoiceOption);
			$query_slider = array(
				'post_type' => 'product',
				'posts_per_page' => $maxOption,
				'order' => $orderOption,
				'orderby' => $orderbyOption,
				'post__not_in' => $excludedArray,
				'tax_query'  => array(
					array(
						'taxonomy'      => 'product_cat',
						'field' => 'term_id', //This is optional, as it defaults to 'term_id'
						'terms'         => $catArray,
						'operator'      => 'IN' // Possible values are 'IN', 'NOT IN', 'AND'.
					),
					array(
						'taxonomy'      => 'product_visibility',
						'field'         => 'slug',
						'terms'         => 'exclude-from-catalog', // Possibly 'exclude-from-search' too
						'operator'      => 'NOT IN'
					)
				)
			 );
			
		}
		$slider_query = new WP_Query( $query_slider );

		$mtfeatured .= '<div class="mt-woofeatured-slider">';

		$i = 1;
		while ( $slider_query->have_posts() ) {
			$slider_query->the_post();
				$pid = get_the_ID();
			
			$mtfeatured .= '<div class="mt-product-slide slide-'.$i.'">';
			$mtfeatured .= '<a href="' . get_permalink() . '" class="mt-product-link">';
			if ( has_post_thumbnail() ) {
				if ($i == 1) {
					$mtfeatured .= '<img src="'. get_the_post_thumbnail_url( '',$imageSize ) .'" class="mt-product-image skip-lazy" alt=""/>';
				} else {
					$mtfeatured .= '<img src="'. get_the_post_thumbnail_url( '',$imageSize ) .'" class="mt-product-image" alt=""/>';
				}
			}
				if($titleOption === 'Yes'){
					$mtfeatured .= '<div class="mt-product-title">';
					$mtfeatured .= get_the_title();
					$mtfeatured .= '</div>';
				}
				if(($priceOption === 'Yes') && ($addToCart === 'No')){
					$mtfeatured .= '<span>$';
					$mtfeatured .= get_post_meta( $pid, '_price', true );
					$mtfeatured .= '</span>';
				}
				if($typeOption === 'All'){
					if (has_term('featured', 'product_visibility')) {
						$mtfeatured .= '<span class="featured-product">Featured</span>';
					}
				}
				
			$mtfeatured .= '</a>';
			if($addToCart == 'Yes') {
				$mtfeatured .= do_shortcode("[add_to_cart id='$pid']");
			}
			$mtfeatured .= '</div>';
			
			$i++;
		}
		$mtfeatured .= '</div>';
		
		wp_reset_postdata();
		
		wp_enqueue_style( 'slickCSS' );
		wp_enqueue_style( 'slickCSS1' );
		wp_enqueue_style( 'sliderCSS' );
		wp_enqueue_script( 'slickJS' );
		
		add_action('wp_footer', 'add_this_script_footer');
		
		return $mtfeatured;		
	}
}
	
add_shortcode('mt-product-carousel', 'MTProductCarouselShortcode');

/*SLICK JQUERY*/

function add_this_script_footer(){ 

	$slickOptions = get_option('mt_featured_settings' );
	if (isset($slickOptions['slick-settings'])) {
?>

	<script type="text/javascript">
		jQuery(function(){
		  jQuery('.mt-woofeatured-slider').slick({<?php 
				$slickOption = $slickOptions['slick-settings'];
				if ($slickOption != '') {
					echo $slickOption;
				} else {
					echo 'dots: true, arrows: false, infinite: false, speed: 300, slidesToShow: 3, slidesToScroll: 1, lazyLoad: \'ondemand\', autoplay: true, speed: 3000, autoplaySpeed: 3500, responsive: [ { breakpoint: 768, settings: { slidesToShow: 2 } }, { breakpoint: 480, settings: { slidesToShow: 1 } } ]';
				} 
			?>});
		});
	</script>

<?php } 
} 

function mt_activation_actions(){
    do_action( 'mt_extension_activation' );
}

register_activation_hook( __FILE__, 'mt_activation_actions' );

// Set default values here
function mt_default_options(){
    $default = array(
        'exclude-slick'     => '1',
		'orderby'     => 'title',
		'order'     => 'ASC',
		'product_add_to_cart','No'
    );
    update_option( 'mt_featured_settings', $default );
}
add_action( 'mt_extension_activation', 'mt_default_options' );

?>